@@ -42,22 +42,22 @@
 #define QT_FEATURE_libinput 1
 #define QT_FEATURE_libinput_axis_api 1
 #define QT_FEATURE_linuxfb 1
-#define QT_FEATURE_mirclient -1
 #define QT_FEATURE_mtdev 1
 #define QT_FEATURE_multiprocess 1
 #define QT_FEATURE_png 1
+#define QT_FEATURE_raster_64bit 1
 #define QT_FEATURE_system_harfbuzz 1
 #define QT_FEATURE_system_jpeg 1
 #define QT_FEATURE_system_png 1
 #define QT_FEATURE_system_xcb 1
 #define QT_FEATURE_tslib 1
 #define QT_FEATURE_tuiotouch 1
+#define QT_FEATURE_vkgen 1
 #define QT_FEATURE_vnc 1
 #define QT_FEATURE_xcb_egl_plugin 1
 #define QT_FEATURE_xcb_glx_plugin 1
 #define QT_FEATURE_xcb_glx 1
-#define QT_FEATURE_xcb_native_painting 1
+#define QT_FEATURE_xcb_native_painting -1
 #define QT_FEATURE_xcb_sm 1
 #define QT_FEATURE_xcb_xinput 1
 #define QT_FEATURE_xkb 1
-#define QT_FEATURE_xrender 1
